@@ -49,3 +49,19 @@ def shell_exec(command):
 def kill_pid(pid, signal):
     """Sends a signal to the process with the given id."""
     shell_exec("/bin/kill -%d %d" % (signal, pid))
+
+
+def which(program):
+    def is_exe(fpath):
+        return os.path.exists(fpath) and os.access(fpath, os.X_OK)
+
+    fpath, fname = os.path.split(program)
+    if fpath:
+        if is_exe(program):
+            return program
+    else:
+        for path in os.environ["PATH"].split(os.pathsep):
+            exe_file = os.path.join(path, program)
+            if is_exe(exe_file):
+                return exe_file
+    return None
